IF OBJECT_ID('tmp_OperationData') IS NOT NULL
	DROP TABLE tmp_OperationData;

DECLARE @CmdTpl NVARCHAR(MAX) =
'IF OBJECT_ID(''dbo.[##Name##_backup]'') IS NOT NULL
	DROP TABLE dbo.[##Name##_backup];';
DECLARE @Cmd NVARCHAR(MAX);

DECLARE @Name SYSNAME;

DECLARE cur CURSOR FAST_FORWARD READ_ONLY LOCAL FOR
	WITH cte AS (
		SELECT DISTINCT
			ss.Name,
			CASE
				WHEN ss.Name = 'SupplyPaymentTemplateItem' THEN 'SysSupplyPaymTemplItemLcz'
				WHEN ss.Name = 'OpportunityParticipantRole' THEN 'SysOpportunityParticipRoleLcz'
				WHEN ss.Name = 'EmailTemplateRecipientType' THEN 'SysEmailTemplRecipientTypeLcz'
				WHEN ss.Name = 'SynchronizationProcessState' THEN 'SysSyncProcessStateLcz'
				WHEN ss.Name = 'GlobalDuplicateSearchStatus' THEN 'SysGlobalDuplSearchStatusLcz'
				WHEN ss.Name = 'SysEntitySchemaColRightLevel' THEN 'SysEntitySchColRightLevelLcz'
				WHEN ss.Name = 'EntitySchemaRecRightOperation' THEN 'SysEntitySchRecRightOprLcz'
				WHEN ss.Name = 'SysEntitySchemaParentAsscType' THEN 'SysEntitySchParentAsscTypeLcz'
				WHEN ss.Name = 'SysEntitySchemaRecOprRightLvl' THEN 'SysEntitySchRecOprRightLvlLcz'
				WHEN ss.Name = 'SysEntitySchemaRecRightSource' THEN 'SysEntitySchRecRightSourceLcz'
				WHEN ss.Name = 'MailboxForIncidentRegistration' THEN 'SysMailboxForIncidentRegisLcz'
				WHEN LEFT(ss.Name, 3) = 'Sys' THEN ss.Name + 'Lcz'
				ELSE 'Sys' + ss.Name + 'Lcz'
			END AS LczName
		FROM SysSchema ss
		JOIN Lookup l ON ss.UId = l.SysEntitySchemaUId
		JOIN INFORMATION_SCHEMA.TABLES ist ON ist.TABLE_NAME = ss.Name
		JOIN INFORMATION_SCHEMA.columns isc ON isc.TABLE_NAME = ss.Name
		WHERE ist.TABLE_TYPE <> 'VIEW'
			AND isc.COLUMN_NAME = 'Name'
			AND ss.Name <> 'ExcelImportLog'
			AND ss.Name <> 'HeaderProperty'
		UNION SELECT 'DuplicatesRule', 'SysDuplicatesRuleLcz' FROM SysSchema
		UNION SELECT 'QualifyStatusDecoupling', NULL FROM SysSchema
	)
	SELECT DISTINCT cte.Name AS EntityName FROM cte UNION
	SELECT DISTINCT cte.LczName AS EntityName FROM cte
	WHERE OBJECT_ID(cte.LczName) IS NOT NULL;

OPEN cur;
FETCH NEXT FROM cur INTO @Name;

WHILE @@FETCH_STATUS = 0 BEGIN
	SET @Cmd = REPLACE(@CmdTpl, '##Name##', @Name);
	EXEC dlv.tsp_Execute @Cmd;
	FETCH NEXT FROM cur INTO @Name;
END

CLOSE cur;
DEALLOCATE cur;