﻿IF (SELECT TOP (1) 1 FROM SysLic) IS NULL
	RETURN;

--region Restore SysSettings
IF OBJECT_ID('CheckSysSettingsUpdate') IS NOT NULL
BEGIN
	PRINT('DROP TRIGGER CheckSysSettingsUpdate');
	DROP TRIGGER CheckSysSettingsUpdate;
END

UPDATE SysSettings
SET
	[Name] = ussl.[Name],
	[ValueTypeName] = ussl.[ValueTypeName], 
	[IsPersonal] = ussl.[IsPersonal], 
	[IsCacheable] = ussl.[IsCacheable], 
	[SysFolderId] = ussl.[SysFolderId],
	[Code] = ussl.[Code],
	[Description] = ussl.[Description],
	[ReferenceSchemaUId] = ussl.[ReferenceSchemaUId],
	[IsSSPAvailable] = ussl.[IsSSPAvailable]
FROM SysSettings ss
INNER JOIN
	(SELECT
		innerLog.*
	FROM UpdatedSysSettingsLog innerLog,
		(SELECT Id,
			MIN(CreatedOn) AS CreatedOn
			FROM UpdatedSysSettingsLog
			GROUP BY Id) AS firstLog
	WHERE
		innerLog.Id = firstLog.Id
		AND innerLog.CreatedOn = firstLog.CreatedOn) ussl
	ON ussl.Id = ss.Id
WHERE
	(
		ussl.[Name] <> ss.[Name]
		OR ussl.[ValueTypeName] <> ss.[ValueTypeName]
		OR ussl.[IsPersonal] <> ss.[IsPersonal]
		OR ussl.[IsCacheable] <> ss.[IsCacheable]
		OR (ussl.[SysFolderId] <> ss.[SysFolderId]
			OR (ussl.[SysFolderId] IS NOT NULL AND ss.[SysFolderId] IS NULL)
		)
		OR ussl.[Code] <> ss.[Code]
		OR ussl.[Description] <> ss.[Description]
		OR (ussl.[ReferenceSchemaUId] <> ss.[ReferenceSchemaUId]
			OR (ussl.[ReferenceSchemaUId] IS NOT NULL AND ss.[ReferenceSchemaUId] IS NULL)
		)
		OR ussl.[IsSSPAvailable] <> ss.[IsSSPAvailable]		
	)
--endregion

--region Restore SysSettings values
DECLARE @forceUpdateSysSettingsCode AS TABLE (Code NVARCHAR(50));
INSERT INTO @forceUpdateSysSettingsCode
	(Code)
VALUES
	('WelcomeScreenVideoUrl'),
	('ConfigurationVersion'),
	('ApiUrl'),
	('ScriptTemplate'),
	('PeriodActualizeBulkEmailRecipients'),
	('SalesDashboardsWithPrefix'),
	('SalesDashboardPrefix'),
	('CaseOrigin'),
	('CaseStatus'),
	('CasePriority'),
	('SatisfactionLevel'),
	('FieldForcePackageUrl');

IF OBJECT_ID('CheckSysSettingsValueUpdate') IS NOT NULL
BEGIN
	PRINT('DROP TRIGGER CheckSysSettingsValueUpdate');
	DROP TRIGGER CheckSysSettingsValueUpdate;
END

UPDATE SysSettingsValue
SET
	[SysAdminUnitId] = ussvl.[SysAdminUnitId],
	[IsDef] = ussvl.[IsDef], 
	[TextValue] = ussvl.[TextValue], 
	[IntegerValue] = ussvl.[IntegerValue], 
	[FloatValue] = ussvl.[FloatValue],
	[BooleanValue] = ussvl.[BooleanValue],
	[DateTimeValue] = ussvl.[DateTimeValue],
	[GuidValue] = ussvl.[GuidValue],
	[BinaryValue] = ussvl.[BinaryValue]
FROM SysSettingsValue ssv
INNER JOIN
	(SELECT
		innerLogValue.*
	FROM UpdatedSysSettingsValuesLog innerLogValue,
		(SELECT SysSettingsId,
			MIN(CreatedOn) AS CreatedOn
			FROM UpdatedSysSettingsValuesLog
			GROUP BY SysSettingsId) AS firstLogValue
	WHERE
		innerLogValue.SysSettingsId = firstLogValue.SysSettingsId
		AND innerLogValue.CreatedOn = firstLogValue.CreatedOn) ussvl
	ON ussvl.Id = ssv.Id
INNER JOIN SysSettings ss ON ss.Id = ssv.SysSettingsId
WHERE
	(
		ussvl.[SysAdminUnitId] <> ssv.[SysAdminUnitId]
		OR ussvl.[IsDef] <> ssv.[IsDef]
		OR ussvl.[TextValue] <> ssv.[TextValue]
		OR ussvl.[IntegerValue] <> ssv.[IntegerValue]
		OR ussvl.[FloatValue] <> ssv.[FloatValue]
		OR ussvl.[BooleanValue] <> ssv.[BooleanValue]
		OR (ussvl.[DateTimeValue] <> ssv.[DateTimeValue]
			OR (ussvl.[DateTimeValue] IS NOT NULL AND ssv.[DateTimeValue] IS NULL)
		)
		OR (ussvl.[GuidValue] <> ssv.[GuidValue]
			OR (ussvl.[GuidValue] IS NOT NULL AND ssv.[GuidValue] IS NULL)
		)
		OR (ussvl.[BinaryValue] <> ssv.[BinaryValue]
			OR (ussvl.[BinaryValue] IS NOT NULL AND ssv.[BinaryValue] IS NULL)
		)
	)
	AND Code NOT IN (SELECT Code FROM @forceUpdateSysSettingsCode);
--endregion